GlobeForegroundRenderer class

Globe.GL-style foreground renderer for points and connections.

This class calculates positions for all elements and renders them with proper animations, transitions, and GPU acceleration where possible.

Constructors

GlobeForegroundRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateConnectionPositions({required List<AnimatedPointConnection> connections, required double radius, required double rotationY, required double rotationZ, required Size canvasSize, required DateTime now}) List<ArcRenderData>
Calculate render data for all connections (Globe.GL style)
calculatePointPositions({required List<Point> points, required double radius, required double rotationY, required double rotationZ, required Size canvasSize, required DateTime now}) List<PointRenderData>
Calculate render data for all points
calculateSatellitePositions({required List<Satellite> satellites, required double radius, required double rotationY, required double rotationZ, required Size canvasSize, required DateTime now}) List<SatelliteRenderData>
Calculate render data for all satellites
cleanupRemovedElements(List<Point> points, List<AnimatedPointConnection> connections, [List<Satellite>? satellites]) → void
Clean up transitions for removed elements
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited