GpuForegroundPainter class

GPU-accelerated foreground painter using Fragment Shaders

Inheritance

Constructors

GpuForegroundPainter({required List<PointRenderData> points, required List<ArcRenderData> arcs, required List<SatelliteRenderData> satellites, required double radius, required Offset center, Offset? hoverPoint, Offset? clickPoint, bool skipSatelliteShapes = false, void onPointHover(String pointId, Offset? position, bool isHovering, bool isVisible)?, void onConnectionHover(String connectionId, Offset? position, bool isHovering, bool isVisible)?, void onSatelliteHover(String satelliteId, Offset? position, bool isHovering, bool isVisible)?, VoidCallback? onPointClicked, String? previousHoveredPointId, String? previousHoveredConnectionId, String? previousHoveredSatelliteId})

Properties

arcs List<ArcRenderData>
final
center Offset
final
clickPoint Offset?
final
hashCode int
The hash code for this object.
no setterinherited
hoverPoint Offset?
final
onConnectionHover → void Function(String connectionId, Offset? position, bool isHovering, bool isVisible)?
final
onPointClicked VoidCallback?
final
onPointHover → void Function(String pointId, Offset? position, bool isHovering, bool isVisible)?
final
onSatelliteHover → void Function(String satelliteId, Offset? position, bool isHovering, bool isVisible)?
final
points List<PointRenderData>
final
previousHoveredConnectionId String?
final
previousHoveredPointId String?
final
previousHoveredSatelliteId String?
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satellites List<SatelliteRenderData>
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
skipSatelliteShapes bool
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant GpuForegroundPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited