Point class

Represents a point on a globe.

Constructors

Point({required GlobeCoordinates coordinates, String? label, Widget? labelBuilder(BuildContext context, Point point, bool isHovering, bool isVisible)?, bool isLabelVisible = false, Offset labelOffset = const Offset(0, 0), required String id, PointStyle style = const PointStyle(), TextStyle? labelTextStyle, VoidCallback? onTap, VoidCallback? onHover})
Creates a new instance of the Point class.

Properties

coordinates → GlobeCoordinates
The coordinates of the point on the globe.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the point.
final
isLabelVisible → bool
Determines whether the label is visible or not.
final
label → String?
The label text of the point.
final
labelBuilder → Widget? Function(BuildContext context, Point point, bool isHovering, bool isVisible)?
A builder function that returns a widget to display as the label of the point.
final
labelOffset → Offset
The offset of the label from the point.
final
labelTextStyle → TextStyle?
The text style of the label.
final
onHover → VoidCallback?
A callback function that is called when the point is hovered over.
final
onTap → VoidCallback?
A callback function that is called when the point is tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ PointStyle
The style of the point.
getter/setter pair

Methods

copyWith({GlobeCoordinates? coordinates, String? label, Widget? labelBuilder(BuildContext context, Point point, bool isHovering, bool isVisible)?, bool? isLabelVisible, Offset? labelOffset, String? id, PointStyle? style, TextStyle? labelTextStyle, VoidCallback? onTap, VoidCallback? onHover}) → Point
Creates a copy of the Point object with the specified properties overridden.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited